package Token;
sub authenticate{
	my ($self,$url_connection)= @_;
}

=head1 NAME

 com::zoho::api::authenticator::Token - This class verifies and sets token to APIHTTPConnector instance

=head1 DESCRIPTION

=head2 METHODS

=over 4

=item C<authenticate>

This method to set authentication token to APIHTTPConnector instance

Param url_connection :  A APIHTTPConnector class instance.


=back

=cut
1;
